---
title: 나이스페이먼츠 상점아이디 추가 절차
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 서비스 추가/변경
seo:
  title: 나이스페이먼츠 상점아이디 추가 절차
  description: >-
    나이스페이먼츠의 상점아이디(사이트코드) 추가절차 안내입니다. 추가 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되며, 상점아이디를
    추가하실 수 있는 경우를 확인하세요.
  keywords:
    - 나이스페이먼츠
    - 서비스추가/변경
tags:
  - 나이스페이먼츠
  - 서비스추가/변경
pgCompanies:
  - 나이스페이먼츠
searchTags:
  - 나이스페이
  - 나이스페이먼츠
  - 나이스페이먼츠 MID 추가
  - 나이스페이먼츠 서비스 추가
  - 나이스페이먼츠 상점아이디 추가
  - 사이트추가
  - 서비스추가
  - 서비스 추가
  - 사이트 추가
  - 나이스페이 서비스 추가
  - 나이스페이상점아이디추가
  - 나이스페이 상점아이디 추가
  - MID 추가
  - MID추가
  - 상점아이디추가
  - 상점아이디 추가
datetime: 2024-02-16T15:00:00.000Z
---

<Callout content="나이스페이먼츠 상점아이디 추가 절차를 안내해드립니다. 추가되는 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되는 점 참고해주세요." />

<Callout title="포트원 기준 결제대행사 수수료 보러가기↗" />

### **상점아이디 추가 케이스**

<Callout content="포트원 정책에 의하여 기존에 포트원을 통하지 않고 계약된 상점아이디는 포트원 서비스 사용이 불가합니다. 새로운 포트원용 상점아이디를 추가 발급 받으신 후 이용해주시기 바랍니다." title="참고사항" icon="💡" />

- 이미 나이스페이먼츠와 직접 계약(독립몰)이 되어있다가 포트원으로 연동하고자 하시는 경우
- 다른 호스팅사(제휴사)를 통해 나이스페이먼츠와 계약 되어있다가 포트원으로 연동하시는 경우
- 새로운 서비스가 추가되는 경우 (=심사를 다시 받아야 하는 경우)
- 기존 서비스와 결제/정산을 분리하고자 하시는 경우
- 심사받은 적 없는 연동방식을 추가하시는 경우 (ex. 일반결제 사용중에 정기결제 추가시)

### **신청방법**

#### **신청 경로**

1. **나이스페이와 직접 계약(독립몰) 또는 타 제휴사(호스팅사)를 통해 이미 계약된 경우**\
   (신규 가입신청과 동일한 절차로 진행해주시기 바랍니다.)

<Indent level="1">

- **포트원 관리자콘솔**>좌측상단 전자결제신청 클릭>결제서비스신청>\[전자결제 직접신청]선택>접수완료
- 3영업일내 나이스페이먼츠 계약부서에서 직접 연락을 드립니다.

</Indent>

<Callout content="1. 기존 나이스페이먼츠와 계약이 되어있으셔도 포트원(호스팅)을 통해 신규 계약으로 진행되므로 기존 계약 진행시 제출한 구비서류와 별개로 전체 신규계약 구비 서류 제출 절차가 필요합니다. 
(이전에 접수하신 이력과 관계없이 신규 제출 필요)

2. 기존에 카드사 심사를 받은 결제수단을 그대로 이용하실 경우 추가 카드사 심사 진행 없이 진행 가능합니다. 단, 업종 및 판매 서비스에 따른 당사 심사는 진행되어야 하며 기존 카드사 심사 진행 이후 1년간 미거래 상태일 시 카드사 측에서 해지처리될 수 있어 재심사 필요합니다.
(업종은 기존과 동일하여도 판매 서비스 형태, 서비스 제공기간 등은 심사 진행되어야 합니다.)" title="참고사항" icon="💡" />

**2**.**포트원을 통해 계약되어있는 상태에서 서비스 추가(MID)이 필요한 경우**

포트원을 통해 이미 나이스페이먼츠 이용중에, 서비스(사이트 또는 결제방식(일반/정기결제)가 추가된 경우 신규 계약이 아닌 MID추가 계약으로 진행이 가능합니다.\
\
아래 작성 내용을 참고하여 관련 내용을 포트원 고객지원팀으로 전달주시면 나이스페이먼츠측으로 전달드리겠습니다.  나이스페이먼츠 계약부서에서 내용 확인 후 필요한 절차를 2\~3영업일 내 담당자님께 직접 메일 안내드릴 예정입니다.

- 포트원 고객지원팀 : [cs@portone.io↗](mailto:cs@portone.io)

#### **전달 내용**

- 상호명 :
- 사업자번호 :
- 대표자명 :
- 포트원을 통해 연동하실 서비스(사이트 또는 앱다운로드) 주소 :
- 포트원을 통해 연동하실 서비스 유형(업종) :
- 고객사 담당자 정보 : 성함 / 연락처 / 이메일주소
- 기존에 이용중이셨던 나이스페이먼츠 상점아이디(MID) :
- 기존 상점아이디의 결제수수료율 **(결제수단별 기재필요)** :
  - 기존에도 포트원을 통해 서비스 이용중이셨다면 전달주지 않으셔도 됩니다.
  - 카드의 경우 적용중인 **영중소 구분**까지 반드시 적어주시기 바랍니다.\
    [영중소 수수료율 기준 보러가기↗](https://help.portone.io/content/small-business-commission-fee)
- 원하시는 결제 방식 (ex. 일반결제, 정기결제, 수기결제) :
- 원하시는 결제 수단 (ex. 카드, 계좌이체, 휴대폰결제) :

##### **3. 수수료 조정이 필요한 경우**

\
<사업자 정보>

- 상호명 :
- 사업자번호 :
- 대표자명 :
- 포트원을 통해 연동하실 서비스(사이트 또는 앱다운로드) 주소 :
- 포트원을 통해 연동하실 서비스 유형(업종) :
- 담당자 정보 : 성함 / 연락처 / 이메일주소

**<나이스페이먼츠** **계약** **정보>**

- 기존 나이스페이 상점아이디(MID) :
- 기존 나이스페이 가맹점 결제수수료율 : 카드( 영중소 구분 필수 기재), 실시간계좌이체, 가상계좌 등 사용중인 결제수단별 수수료율)
- 기존 나이스페이를 통해 발생된 최근 3개월간 평균 매출금액 : 서비스 준비중(구축중)인 경우 '없음'으로 기재
- 포트원을 통해 이용하실 결제방식(수단) : ex) 일반결제(카드,계좌이체,가상계좌) , 정기결제
